@@ -9,35 +9,45 @@ CLI commands
 import types, argparse, locale
 from pathlib import Path
 
-from cue.cli.ledger import Ledger
-
 locale.setlocale(locale.LC_ALL, '') # '' -> ledger['locale']), hmmm
 
 def init(*args):
     """initialise a cue ledger - part 1"""
-    Ledger().boilerplate()
+    from cue.ledger import Ledger
+    Ledger.boilerplate()
 
 def commit(*args):
     """process temp files"""
     for path in Path().glob('**/temp__*'):
         cls_name = path.stem.split('__')[1]
         if cls_name == 'Ledger':
-            Ledger().commit()
+            from cue.ledger import Ledger
+            Ledger.commit()
         elif cls_name == 'Invoice':
-            from cue.cli.invoice import Invoice
+            from cue.invoice import Invoice
             invoice = Invoice.parse(path)
             invoice.issue()
 
 def invoice(*args):
     """invoice a customer"""
-    from cue.cli.invoice import Invoice
+    from cue.invoice import Invoice
     customer = ' '.join(args)
     Invoice.boilerplate(customer)
 
 def clean(*args):
     """remove cue ledger from dir or parent"""
-    import cue.ledger
-    cue.ledger.Ledger().clean()
+    from cue.ledger import Ledger
+    Ledger().clean()
+
+def cat(*args):
+    """respresent the item using ascii art"""
+    path = Path(args[0])
+    if path.suffix == '.acc':
+        from cue.account import Account
+        item = Account(path)
+    else:
+        item = path.read_text()
+    print(str(item))
 
 def echo(*args):
     """echo args"""
