@@ -19,3 +19,10 @@ class TestAcc(UnitTest):
             assert 'invalid caller' in str(e)
         else:
             raise RuntimeError('no exception was raised')
+
+    def test_acc_3(self):
+        """auto creates account file"""
+        from cue.account import Account
+        a = Account.create('111 - Test', 'DR')
+        with a.path.open() as f:
+            assert 'bal:' in f.read()
